
# Slot: name




URI: [nwb_schema_language:CompoundDtype_name](https://w3id.org/p2p_ld/nwb-schema-language/CompoundDtype_name)


## Domain and Range

[CompoundDtype](CompoundDtype.md) &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents

 *  is_a: [name](name.md)

## Children


## Used by

 * [CompoundDtype](CompoundDtype.md)
